@@ -1,8 +1,11 @@
+use std::path::PathBuf;
+
 pub type Result<T> = std::result::Result<T, FileRotationError>;
 
 #[non_exhaustive]
 #[derive(Debug)]
 pub enum FileRotationError {
+    NotAFile(PathBuf),
     Io(std::io::Error),
 }
 
@@ -14,6 +17,9 @@ impl std::fmt::Display for FileRotationError {
             FileRotationError::Io(err) => {
                 write!(f, "FileRotation io error: {err}")
             }
+            FileRotationError::NotAFile(path) => {
+                write!(f, "path {path:?} is not a file")
+            }
         }
     }
 }
